@@ -60,7 +60,7 @@ async def get_rest_devices(
         mqtt_connection.connect().result()
         _LOGGER.debug(f"mqtt connection connected")
     except Exception as e:
-        _LOGGER.error('MQTT connection failed with exception {}'.format(e))
+        _LOGGER.error(f'MQTT connection failed with exception {e}')
         raise e
 
     shadow_client = IotShadowClient(mqtt_connection)
@@ -70,12 +70,14 @@ async def get_rest_devices(
             return RestPlus(
                 device_name=iot_device["name"],
                 thing_name=iot_device["thingName"],
+                mac=iot_device["macAddress"],
                 shadow_client=shadow_client,
             )
         elif iot_device["product"] in ["riot", "riotPlus"]:
             return RestIot(
                 device_name=iot_device["name"],
                 thing_name=iot_device["thingName"],
+                mac=iot_device["macAddress"],
                 shadow_client=shadow_client,
                 favorites=favorites_map[iot_device["macAddress"]],
             )
@@ -83,6 +85,7 @@ async def get_rest_devices(
             return RestMini(
                 device_name=iot_device["name"],
                 thing_name=iot_device["thingName"],
+                mac=iot_device["macAddress"],
                 shadow_client=shadow_client,
             )
 
